@@ -28,10 +28,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=cc
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS="-I/usr/local/include"
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS="-L/usr/local/lib"
+	if [ -z ${CXX+x} ]; then
+		CXX=c++
 	fi
+	set_common
 }
