@@ -9,6 +9,7 @@ SHARED_FLAGS=-DHURD=1\\
 	-DUNIX=1\\
 	-D_FORTIFY_SOURCE=2\\
 	-D_GNU_SOURCE=1\\
+	-I/usr/local/include\\
 	-O2\\
 	-Wall\\
 	-fstack-protector-strong\\
@@ -19,7 +20,8 @@ CFLAGS=\$(SHARED_FLAGS) -std=c11\\
 	-Wsign-compare -Wstrict-prototypes
 CXX=g++
 CXXFLAGS=\$(SHARED_FLAGS) -std=c++17
-LDFLAGS=-Wl,-z,now\\
+LDFLAGS=-L/usr/local/lib\\
+	-Wl,-z,now\\
 	-Wl,-z,relro
 LDLIBS=-lcrypto\\
 	-lcurl\\
@@ -32,10 +34,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=gcc
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS=""
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS=""
+	if [ -z ${CXX+x} ]; then
+		CXX=g++
 	fi
+	set_common
 }
