@@ -11,6 +11,7 @@ SHARED_FLAGS=-DLINUX=1\\
 	-D_POSIX_C_SOURCE=200809L\\
 	-D_XOPEN_SOURCE=500\\
 	-D_XOPEN_SOURCE_EXTENDED=1\\
+	-I/usr/local/include\\
 	-O2\\
 	-Wall\\
 	-fstack-protector-strong\\
@@ -21,7 +22,8 @@ CFLAGS=\$(SHARED_FLAGS) -std=c11\\
 	-Wsign-compare -Wstrict-prototypes
 CXX=g++
 CXXFLAGS=\$(SHARED_FLAGS) -std=c++17
-LDFLAGS=-Wl,-z,now\\
+LDFLAGS=-L/usr/local/lib\\
+	-Wl,-z,now\\
 	-Wl,-z,relro
 LDLIBS=-lcrypto\\
 	-lcurl\\
@@ -34,10 +36,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=gcc
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS=""
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS=""
+	if [ -z ${CXX+x} ]; then
+		CXX=g++
 	fi
+	set_common
 }
