@@ -10,6 +10,7 @@ SHARED_FLAGS=-DLINUX=1\\
 	-D_POSIX_C_SOURCE=200809L\\
 	-D_XOPEN_SOURCE=500\\
 	-D_XOPEN_SOURCE_EXTENDED=1\\
+	-I/usr/local/include\\
 	-O2\\
 	-Wp,-I/usr/include/x86_64-linux-gnu\\
 	-errtags\\
@@ -22,7 +23,9 @@ CC=suncc
 CFLAGS=\$(SHARED_FLAGS) -std=c11
 CXX=sunCC
 CXXFLAGS=\$(SHARED_FLAGS) -std=c++14
-LDFLAGS=-xannotate -xprevise
+LDFLAGS=-L/usr/local/lib\\
+	-xannotate\\
+	-xprevise
 LDLIBS=-lcrypto\\
 	-lcurl\\
 	-lncursesw\\
@@ -34,10 +37,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=suncc
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS=""
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS=""
+	if [ -z ${CXX+x} ]; then
+		CXX=sunCC
 	fi
+	set_common
 }
