@@ -9,6 +9,7 @@ SHARED_FLAGS=-DNCURSES_OPAQUE=0\\
 	-DOS_X=1\\
 	-DUNIX=1\\
 	-D_XOPEN_SOURCE_EXTENDED=1\\
+	-I/usr/local/include\\
 	-I/usr/local/opt/libressl/include\\
 	-O2\\
 	-Wall\\
@@ -17,7 +18,8 @@ CC=clang
 CFLAGS=\$(SHARED_FLAGS) -std=c11
 CXX=clang++
 CXXFLAGS=\$(SHARED_FLAGS) -std=c++17
-LDFLAGS=-L/usr/local/opt/libressl/lib
+LDFLAGS=-L/usr/local/lib\\
+	-L/usr/local/opt/libressl/lib
 LDLIBS=-lcrypto\\
 	-lcurl\\
 	-lncurses\\
@@ -29,10 +31,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=clang
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS=""
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS=""
+	if [ -z ${CXX+x} ]; then
+		CXX=clang++
 	fi
+	set_common
 }
