@@ -7,6 +7,7 @@ os_NETBSD () {
 SHARED_FLAGS=-DBSD=1\\
 	-DUNIX=1\\
 	-D_XOPEN_SOURCE_EXTENDED=1\\
+	-I/usr/local/include\\
 	-I/usr/pkg/include/ncursesw\\
 	-I/usr/pkg/include\\
 	-Wall
@@ -14,7 +15,8 @@ CC=cc
 CFLAGS=\$(SHARED_FLAGS) -std=c11
 CXX=c++
 CXXFLAGS=\$(SHARED_FLAGS) -std=c++17
-LDFLAGS=-L/usr/pkg/lib\\
+LDFLAGS=-L/usr/local/lib\\
+	-L/usr/pkg/lib\\
 	-Wl,-rpath,/usr/pkg/lib
 LDLIBS=-lcrypto\\
 	-lcurl\\
@@ -27,10 +29,8 @@ EOF
 	if [ -z ${CC+x} ]; then
 		CC=cc
 	fi
-	if [ -z ${CFLAGS+x} ]; then
-		CFLAGS=""
-	fi
-	if [ -z ${LDFLAGS+x} ]; then
-		LDFLAGS=""
+	if [ -z ${CXX+x} ]; then
+		CXX=c++
 	fi
+	set_common
 }
