@@ -56,6 +56,7 @@
 #include "commands/colormap.h"
 #include "commands/connect.h"
 #include "commands/echo.h"
+#include "commands/fetchdic.h"
 #include "commands/ignore.h"
 #include "commands/invite.h"
 #include "commands/jp.h"
@@ -87,7 +88,7 @@ static PTEXTBUF_ELMT	element = NULL;
 #include "commandhelp.h"
 
 static struct cmds_tag {
-	char		*cmd;
+	STRING		 cmd;
 	CMD_HANDLER_FN	 fn;
 	bool		 requires_connection;
 	const char**	 usage;
@@ -111,6 +112,7 @@ static struct cmds_tag {
 	{ "disconnect",  cmd_disconnect,  false, disconnect_usage,  ARRAY_SIZE(disconnect_usage),  false },
 	{ "echo",        cmd_echo,        false, echo_usage,        ARRAY_SIZE(echo_usage),        false },
 	{ "exlist",      cmd_exlist,      true,  exlist_usage,      ARRAY_SIZE(exlist_usage),      true  },
+	{ "fetchdic",    cmd_fetchdic,    false, fetchdic_usage,    ARRAY_SIZE(fetchdic_usage),    false },
 	{ "group",       cmd_group,       true,  group_usage,       ARRAY_SIZE(group_usage),       false },
 	{ "help",        cmd_help,        false, help_usage,        ARRAY_SIZE(help_usage),        false },
 	{ "ignore",      cmd_ignore,      false, ignore_usage,      ARRAY_SIZE(ignore_usage),      false },
@@ -163,7 +165,7 @@ static struct cmds_tag {
 	for (struct cmds_tag *sp = &cmds[0]; sp < &cmds[ARRAY_SIZE(cmds)]; sp++)
 
 static void
-add_to_history(const char *string)
+add_to_history(CSTRING string)
 {
 	const int tbszp1 = textBuf_size(history) + 1;
 	struct integer_context intctx = {
@@ -200,7 +202,7 @@ add_to_history(const char *string)
 }
 
 static void
-bold_fix(char *string)
+bold_fix(STRING string)
 {
 	char *cp;
 
@@ -236,18 +238,8 @@ get_error_log_size(double *size)
 	return true;
 }
 
-static bool
-got_hits(const char *search_var)
-{
-	FOREACH_COMMAND() {
-		if (!strncmp(search_var, sp->cmd, strlen(search_var)))
-			return true;
-	}
-	return false;
-}
-
 static void
-handle_cmds(const char *data)
+handle_cmds(CSTRING data)
 {
 	PRINTTEXT_CONTEXT ctx;
 
@@ -335,8 +327,8 @@ list_all_commands(void)
 
 	sp = &cmds[0];
 	while (sp < &cmds[ARRAY_SIZE(cmds)]) {
-		const char	*cmd1 = sp->cmd;
-		char		*cmd2, *cmd3;
+		CSTRING  cmd1 = sp->cmd;
+		STRING   cmd2, cmd3;
 
 		if ((sp + 1) < &cmds[ARRAY_SIZE(cmds)] &&
 		    (sp + 2) < &cmds[ARRAY_SIZE(cmds)]) {
@@ -362,7 +354,7 @@ list_all_commands(void)
 }
 
 static void
-output_help_for_command(const char *command)
+output_help_for_command(CSTRING command)
 {
 	PRINTTEXT_CONTEXT ctx;
 
@@ -393,7 +385,7 @@ static void
 swirc_greeting(void)
 {
 	PRINTTEXT_CONTEXT ctx;
-	static const char *logo[] = {
+	static stringarray_t logo = {
 #define USE_LARRY3D_LOGO 1
 #if USE_LARRY3D_LOGO
 		"                     __                              ",
@@ -452,41 +444,41 @@ swirc_greeting(void)
 	printtext(&ctx, " ");
 }
 
-PTEXTBUF
-get_list_of_matching_commands(const char *search_var)
+static void
+add_cmd(PTEXTBUF matches, CSTRING cmd)
 {
-	PTEXTBUF matches;
+	if (textBuf_size(matches) == 0) {
+		if ((errno = textBuf_ins_next(matches, NULL, cmd, -1)) != 0)
+			err_sys("%s: textBuf_ins_next", __func__);
+	} else {
+		if ((errno = textBuf_ins_next(matches, textBuf_tail(matches),
+		    cmd, -1)) != 0)
+			err_sys("%s: textBuf_ins_next", __func__);
+	}
+}
 
-	if (!got_hits(search_var))
-		return NULL;
-
-	matches = textBuf_new();
+PTEXTBUF
+get_list_of_matching_commands(CSTRING search_var)
+{
+	PTEXTBUF matches = textBuf_new();
 
 	FOREACH_COMMAND() {
-		if (!strncmp(search_var, sp->cmd, strlen(search_var))) {
-			if (textBuf_size(matches) == 0) {
-				if ((errno = textBuf_ins_next(matches, NULL,
-				    sp->cmd, -1)) != 0) {
-					err_sys("%s: textBuf_ins_next",
-					    __func__);
-				}
-			} else {
-				if ((errno = textBuf_ins_next(matches,
-				    textBuf_tail(matches), sp->cmd, -1)) != 0) {
-					err_sys("%s: textBuf_ins_next",
-					    __func__);
-				}
-			}
-		}
+		if (!strncmp(search_var, sp->cmd, strlen(search_var)))
+			add_cmd(matches, sp->cmd);
+	}
+
+	if (textBuf_size(matches) == 0) {
+		textBuf_destroy(matches);
+		return NULL;
 	}
 
 	return matches;
 }
 
-char *
+STRING
 get_prompt(void)
 {
-	char			*prompt;
+	STRING			 prompt;
 	int			 ret;
 	static const char	 AFK[] = "(away)";
 	static const size_t	 minimum_cols = sizeof "#abc...: ";
@@ -521,7 +513,7 @@ get_prompt(void)
 
 /* usage: /help [command] */
 void
-cmd_help(const char *data)
+cmd_help(CSTRING data)
 {
 	const bool has_command = !strings_match(data, "");
 
@@ -559,7 +551,7 @@ enter_io_loop(void)
 	history = textBuf_new();
 
 	do {
-		char			*prompt, *line;
+		STRING			 prompt, line;
 		size_t			 len;
 		static const char	 cmd_char = '/';
 
@@ -610,7 +602,7 @@ enter_io_loop(void)
 }
 
 void
-transmit_user_input(const char *winlabel, const char *input)
+transmit_user_input(CSTRING winlabel, CSTRING input)
 {
 	PRINTTEXT_CONTEXT ctx;
 
