@@ -1,5 +1,5 @@
 /* Platform independent networking routines
-   Copyright (C) 2014-2022 Markus Uhlin. All rights reserved.
+   Copyright (C) 2014-2023 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -52,6 +52,7 @@
 #include "network.h"
 #include "printtext.h"
 #include "sig.h"
+#include "socks.hpp"
 #include "strHand.h"
 
 #include "commands/connect.h"
@@ -148,7 +149,7 @@ int g_socket_address_family = AF_UNSPEC;
 *                                                               *
 ****************************************************************/
 
-static class reconnect_context reconn_ctx;
+static reconnect_context reconn_ctx;
 static const int RECVBUF_SIZE = 2048;
 
 /****************************************************************
@@ -198,6 +199,23 @@ conn_check()
 	return 0;
 }
 
+static inline void
+destroy_null_bytes(char *recvbuf, const int bytes_received)
+{
+	int	i, j;
+
+	if (bytes_received < 1)
+		return;
+	for (i = bytes_received - 1; i >= 0; i--) {
+		if (recvbuf[i] != '\0')
+			break;
+	}
+	for (j = 0; j < i; j++) {
+		if (recvbuf[j] == '\0')
+			recvbuf[j] = 'X';
+	}
+}
+
 static void
 connect_hook(void)
 {
@@ -253,8 +271,8 @@ get_and_handle_remaining_bytes(const int bytes_remaining,
 			throw std::runtime_error("read bytes mismatch "
 			    "remaining");
 		}
-
-		UNUSED_VAR(bytes_received);
+		if (memchr(tmp, 0, bytes_received) != NULL)
+			destroy_null_bytes(tmp, bytes_received);
 
 		concatSize = strlen(recvbuf) + strlen(tmp) + 1;
 		concat = static_cast<char *>(xmalloc(concatSize));
@@ -453,7 +471,7 @@ should_check_connection()
 {
 	static int times_called = 0;
 
-	if (times_called > 9) {
+	if (times_called > 15) {
 		times_called = 0;
 		return true;
 	}
@@ -511,15 +529,30 @@ net_connect(const struct network_connect_context *ctx,
 		    ctx->password : ""));
 		if (config_bool("identd", false))
 			identd::start(config_integer(&intctx));
-		get_ip_addresses(res, ctx->server, ctx->port, &ptext_ctx);
+		if (!socks::yesno()) {
+			get_ip_addresses(res, ctx->server, ctx->port,
+			    &ptext_ctx);
+		} else {
+			get_ip_addresses(res,
+			    Config("socks_host"), Config("socks_port"),
+			    &ptext_ctx);
+		}
+
 		establish_conn(res, &ptext_ctx);
 
 		if (res)
 			freeaddrinfo(res);
+		if (socks::yesno()) {
+			std::string err("");
+
+			if (socks::connect(ctx->server, ctx->port, err) == -1)
+				throw std::runtime_error(err);
+		}
 
 		select_send_and_recv_funcs();
 		check_conn_fail();
-		check_hostname(ctx->server, &ptext_ctx);
+		if (!socks::yesno())
+			check_hostname(ctx->server, &ptext_ctx);
 
 		event_welcome_cond_init();
 		net_spawn_listen_thread();
@@ -609,6 +642,12 @@ net_connect_clean_up(void)
 	atomic_swap_bool(&g_connection_in_progress, false);
 }
 
+void
+destroy_null_bytes_exported(char *buf, const int len)
+{
+	destroy_null_bytes(buf, len);
+}
+
 void
 net_irc_listen(bool *connection_lost)
 {
@@ -648,7 +687,7 @@ net_irc_listen(bool *connection_lost)
 			} else if (bytes_received != 1) {
 				if (atomic_load_bool(&g_icb_processing_names))
 					icb_process_event_eof_names();
-				continue;
+				goto _conn_check;
 			}
 
 			ret = snprintf(array, ARRAY_SIZE(array), "%d",
@@ -679,6 +718,11 @@ net_irc_listen(bool *connection_lost)
 					break;
 				}
 			} else if (bytes_received > 0) {
+				if (memchr(recvbuf, 0, bytes_received) !=
+				    NULL) {
+					destroy_null_bytes(recvbuf,
+					    bytes_received);
+				}
 				icb_irc_proxy(length, recvbuf[0], &recvbuf[1]);
 			}
 		} else {
@@ -690,12 +734,18 @@ net_irc_listen(bool *connection_lost)
 			    RECVBUF_SIZE)) == -1) {
 				g_connection_lost = true;
 			} else if (bytes_received > 0) {
+				if (memchr(recvbuf, 0, bytes_received) !=
+				    NULL) {
+					destroy_null_bytes(recvbuf,
+					    bytes_received);
+				}
 				irc_handle_interpret_events(recvbuf,
 				    &message_concat, &state);
 			}
 		}
 
-		if (should_check_connection()) {
+	  _conn_check:
+		if (bytes_received == 0 && should_check_connection()) {
 			if (conn_check() == -1)
 				g_connection_lost = true;
 		}
