@@ -329,16 +329,23 @@ convert_wc(wchar_t wc)
 	mbs[size] = '\0';
 
 #ifdef HAVE_BCI
-	if ((errno = wcrtomb_s(&bytes_written, reinterpret_cast<STRING>(mbs),
-	    size, wc, &ps)) != 0) {
-		err_log(errno, "printtext: %s: wcrtomb_s", __func__);
+	if (wc == L'\0' ||
+	    (errno = wcrtomb_s(&bytes_written, reinterpret_cast<STRING>(mbs),
+	    size, wc, &ps)) != 0 ||
+	    bytes_written == g_conversion_failed ||
+	    bytes_written > size) {
+		if (wc != L'\0')
+			err_log(errno, "printtext: %s: wcrtomb_s", __func__);
 		*mbs = '\0';
 		return mbs;
 	}
 #else
-	if ((bytes_written = wcrtomb(reinterpret_cast<STRING>(mbs), wc, &ps)) ==
-	    g_conversion_failed) {
-		err_log(EILSEQ, "printtext: %s: wcrtomb", __func__);
+	if (wc == L'\0' ||
+	    (bytes_written = wcrtomb(reinterpret_cast<STRING>(mbs), wc, &ps)) ==
+	    g_conversion_failed ||
+	    bytes_written > size) {
+		if (wc != L'\0')
+			err_log(EILSEQ, "printtext: %s: wcrtomb", __func__);
 		*mbs = '\0';
 		return mbs;
 	}
@@ -788,6 +795,8 @@ case_underline(WINDOW *win, bool *is_underline)
 	}
 }
 
+static size_t get_mb_strlen(CSTRING) PTR_ARGS_NONNULL;
+
 /**
  * Get multibyte string length
  */
@@ -799,9 +808,6 @@ get_mb_strlen(CSTRING s)
 	size_t idx = 0;
 	size_t len = 0;
 
-	if (s == NULL)
-		return 0;
-
 	while (true) {
 		const size_t ret = mbrlen(&s[idx], MB_CUR_MAX, NULL);
 
