@@ -50,6 +50,7 @@
 #include "readline.h"
 #include "readlineAPI.h"
 #include "readlineTabCompletion.h"
+#include "spell.h"
 #include "statusbar.h"
 #include "strHand.h"
 #include "terminal.h"
@@ -62,7 +63,8 @@
 *                                                               *
 ****************************************************************/
 
-PREADLINE_POS g_readline_pos = NULL;
+PREADLINE_POS	 g_readline_pos = NULL;
+const int	 g_readline_bufsize = 2000;
 
 bool		g_readline_loop = false;
 bool		g_resize_requested = false;
@@ -79,7 +81,6 @@ bool	g_hist_prev = false;
 
 static PANEL			*readline_pan1 = NULL;
 static PANEL			*readline_pan2 = NULL;
-static const int		 readline_bufsize = 2000;
 static rl_active_panel_t	 panel_state = PANEL1_ACTIVE;
 
 /****************************************************************
@@ -110,11 +111,7 @@ apply_readline_options(WINDOW *win)
 		SCROLLOK(win, 0);
 	}
 
-#if defined(UNIX)
-#define WAIT_TIME_MILLISEC 100
-#elif defined(WIN32)
-#define WAIT_TIME_MILLISEC 0
-#endif
+#define WAIT_TIME_MILLISEC 30
 
 	wtimeout(win, WAIT_TIME_MILLISEC);
 }
@@ -141,7 +138,7 @@ hiLim_isset(WINDOW *win)
  * Write the command-prompt.
  */
 static void
-write_cmdprompt(WINDOW *win, const char *prompt, int size)
+write_cmdprompt(WINDOW *win, CSTRING prompt, int size)
 {
 	int ret;
 
@@ -242,7 +239,7 @@ case_key_backspace(volatile struct readline_session_context *ctx)
 
 		ptr = &ctx->buffer[ctx->bufpos--];
 		(void) wmemmove(ptr - 1, ptr, wcslen(ptr));
-		ctx->buffer[--ctx->n_insert] = 0L;
+		ctx->buffer[--ctx->numins] = 0L;
 
 		mutex_lock(&g_puts_mutex);
 		ret[0] = wmove(ctx->act, term_get_pos(ctx->act).cury,
@@ -265,7 +262,7 @@ case_key_backspace(volatile struct readline_session_context *ctx)
 		 */
 
 		ctx->buffer[--ctx->bufpos] = 0L;
-		ctx->n_insert--;
+		ctx->numins--;
 
 		mutex_lock(&g_puts_mutex);
 		ret[0] = wmove(ctx->act, term_get_pos(ctx->act).cury,
@@ -301,7 +298,7 @@ case_key_dc(volatile struct readline_session_context *ctx)
 
 	ptr = &ctx->buffer[i];
 	(void) wmemmove(ptr - 1, ptr, wcslen(ptr));
-	ctx->buffer[--ctx->n_insert] = 0L;
+	ctx->buffer[--ctx->numins] = 0L;
 
 	mutex_lock(&g_puts_mutex);
 	ret[0] = wdelch(ctx->act);
@@ -386,11 +383,11 @@ case_key_right(volatile struct readline_session_context *ctx)
 /* ---- */
 /* UNIX */
 /* ---- */
-static char *
+static STRING
 finalize_out_string(const wchar_t *buf)
 {
 	const size_t	 size = size_product(wcslen(buf) + 1, MB_LEN_MAX);
-	char		*out = xcalloc(size, 1);
+	STRING		 out = xcalloc(size, 1);
 	size_t		 bytes_convert;
 
 	errno = 0;
@@ -410,11 +407,12 @@ finalize_out_string(const wchar_t *buf)
 /* ----- */
 /* WIN32 */
 /* ----- */
-static char *
+static STRING
 finalize_out_string(const wchar_t *buf)
 {
-	const int size = size_to_int(size_product(wcslen(buf) + 1, MB_LEN_MAX));
-	char *out = xcalloc(size, 1);
+	const int	 size = size_to_int(size_product(wcslen(buf) + 1,
+			     MB_LEN_MAX));
+	STRING		 out = xcalloc(size, 1);
 
 	errno = 0;
 
@@ -468,7 +466,7 @@ handle_key(volatile struct readline_session_context *ctx, wint_t wc,
 		*ptr = wc;
 
 		ctx->bufpos++;
-		ctx->n_insert++;
+		ctx->numins++;
 
 		readline_winsch(ctx->act, wc);
 
@@ -482,7 +480,7 @@ handle_key(volatile struct readline_session_context *ctx, wint_t wc,
 	} else {
 		ctx->buffer[ctx->bufpos] = wc;
 		ctx->bufpos++;
-		ctx->n_insert++;
+		ctx->numins++;
 		readline_waddch(ctx->act, wc);
 	}
 
@@ -493,6 +491,7 @@ handle_key(volatile struct readline_session_context *ctx, wint_t wc,
 	if (check_reset) {
 		if (isInCirculationMode(ctx->tc))
 			readline_tab_comp_ctx_reset(ctx->tc);
+		g_suggs_mode = false;
 	}
 }
 
@@ -518,16 +517,16 @@ handle_mouse(void)
  * Initiate a new readline session
  */
 static struct readline_session_context *
-new_session(const char *prompt)
+new_session(CSTRING prompt)
 {
-	char *prompt_copy = sw_strdup(prompt);
+	STRING prompt_copy = sw_strdup(prompt);
 	struct readline_session_context *ctx = xcalloc(sizeof *ctx, 1);
 
 	ctx->act         = panel_window(readline_pan1);
-	ctx->buffer      = xcalloc(readline_bufsize + 1, sizeof(wchar_t));
+	ctx->buffer      = xcalloc(g_readline_bufsize + 1, sizeof(wchar_t));
 	ctx->bufpos      = 0;
 	ctx->insert_mode = false;
-	ctx->n_insert    = 0;
+	ctx->numins      = 0;
 	ctx->no_bufspc   = false;
 	ctx->prompt      = sw_strdup(prompt);
 	ctx->prompt_size = (int) strlen(squeeze_text_deco(prompt_copy));
@@ -562,6 +561,7 @@ output_help(void)
 	printtext(&ctx, "%s", _("PG DOWN    Scroll down"));
 	printtext(&ctx, "%s", _("Up arrow   History previous"));
 	printtext(&ctx, "%s", _("Down arrow History next"));
+	printtext(&ctx, "%s", _("F2         Spell word"));
 	printtext(&ctx, "%s", _("F3         Scroll nicklist up"));
 	printtext(&ctx, "%s", _("F4         Scroll nicklist down"));
 	printtext(&ctx, "%s", _("F11        Close window"));
@@ -583,11 +583,11 @@ session_destroy(volatile struct readline_session_context *ctx)
 	}
 }
 
-static char *
+static STRING
 process(volatile struct readline_session_context *ctx)
 {
-	char *out;
-	static const int sleep_time_milliseconds = 90;
+	STRING out;
+	static const int sleep_time_milliseconds = 30;
 	wchar_t *buf_p = &g_push_back_buf[0];
 
 	write_cmdprompt(ctx->act, ctx->prompt, ctx->prompt_size);
@@ -595,14 +595,14 @@ process(volatile struct readline_session_context *ctx)
 	do {
 		wint_t wc = 0L;
 
-		ctx->insert_mode = (ctx->bufpos != ctx->n_insert);
-		ctx->no_bufspc = (ctx->n_insert + 1 >= readline_bufsize);
+		ctx->insert_mode = (ctx->bufpos != ctx->numins);
+		ctx->no_bufspc = (ctx->numins + 1 >= g_readline_bufsize);
 
 		if (*buf_p == L'\0' && g_readline_pos != NULL) {
 			if (g_readline_pos->x != ctx->bufpos ||
-			    g_readline_pos->y != ctx->n_insert) {
+			    g_readline_pos->y != ctx->numins) {
 				g_readline_pos->x = ctx->bufpos;
-				g_readline_pos->y = ctx->n_insert;
+				g_readline_pos->y = ctx->numins;
 				statusbar_update_display_beta();
 				readline_top_panel();
 			}
@@ -628,22 +628,24 @@ process(volatile struct readline_session_context *ctx)
 			while (ctx->bufpos != 0) {
 				case_key_left(ctx);
 				ctx->insert_mode =
-				    (ctx->bufpos != ctx->n_insert);
+				    (ctx->bufpos != ctx->numins);
 			}
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- CTRL+A ---------- */
 		case CTRL_E: {
 			while (ctx->insert_mode) {
 				case_key_right(ctx);
 				ctx->insert_mode =
-				    (ctx->bufpos != ctx->n_insert);
+				    (ctx->bufpos != ctx->numins);
 			}
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- CTRL+E ---------- */
 		case CTRL_L:
@@ -671,6 +673,7 @@ process(volatile struct readline_session_context *ctx)
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- KEY_LEFT ---------- */
 		case KEY_RIGHT:
@@ -679,6 +682,7 @@ process(volatile struct readline_session_context *ctx)
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- KEY_RIGHT ---------- */
 		case KEY_BACKSPACE:
@@ -687,11 +691,24 @@ process(volatile struct readline_session_context *ctx)
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- KEY_BACKSPACE ---------- */
 		case KEY_F(1):
 			output_help();
 			break;
+		case KEY_F(2): {
+#ifdef HAVE_HUNSPELL
+			if (!isInCirculationMode(ctx->tc))
+				spell_word_readline(ctx);
+			else
+				printtext_print("err", "Is in tab circulation "
+				    "mode");
+#else
+			printtext_print("err", "No Hunspell support!");
+#endif
+			break;
+		} /* ---------- F2 ---------- */
 		case KEY_F(3):
 			nicklist_scroll_up(g_active_window);
 			break;
@@ -736,6 +753,7 @@ process(volatile struct readline_session_context *ctx)
 
 			if (isInCirculationMode(ctx->tc))
 				readline_tab_comp_ctx_reset(ctx->tc);
+			g_suggs_mode = false;
 			break;
 		} /* ---------- KEY_DC ---------- */
 		case KEY_MOUSE:
@@ -773,8 +791,8 @@ process(volatile struct readline_session_context *ctx)
 
 	write_cmdprompt(ctx->act, "", 0);
 
-	if (ctx->n_insert > 0) {
-		ctx->buffer[ctx->n_insert] = 0L;
+	if (ctx->numins > 0) {
+		ctx->buffer[ctx->numins] = 0L;
 	} else {
 		session_destroy(ctx);
 		return NULL;
@@ -801,6 +819,10 @@ report_wheel_events(void)
 void
 readline_init(void)
 {
+#ifdef HAVE_HUNSPELL
+	spell_init(true);
+#endif
+
 	g_readline_pos = xcalloc(sizeof *g_readline_pos, 1);
 	g_readline_pos->x = -1;
 	g_readline_pos->y = -1;
@@ -820,6 +842,10 @@ readline_init(void)
 void
 readline_deinit(void)
 {
+#ifdef HAVE_HUNSPELL
+	spell_deinit();
+#endif
+
 	free(g_readline_pos);
 	g_readline_pos = NULL;
 
@@ -846,8 +872,8 @@ readline_get_active_pwin(void)
  * @param prompt Prompt
  * @return The read line (dynamically allocated) or NULL
  */
-char *
-readline(const char *prompt)
+STRING
+readline(CSTRING prompt)
 {
 	volatile struct readline_session_context *ctx = NULL;
 
@@ -855,6 +881,7 @@ readline(const char *prompt)
 	case READLINE_PROCESS:
 		g_readline_loop = true;
 		g_resize_requested = false;
+		g_suggs_mode = false;
 		g_hist_next = false;
 		g_hist_prev = false;
 		ctx = new_session(prompt);
@@ -865,7 +892,7 @@ readline(const char *prompt)
 	return NULL;
 }
 
-char *
+STRING
 readline_finalize_out_string_exported(const wchar_t *buf)
 {
 	return finalize_out_string(buf);
@@ -888,7 +915,7 @@ void
 readline_mouse_init(void)
 {
 	if (config_bool("mouse", false)) {
-		const char *str = Config("mouse_events");
+		CSTRING str = Config("mouse_events");
 
 		if (strings_match(str, "all") || strings_match(str, "ALL"))
 			(void) mousemask(ALL_MOUSE_EVENTS, NULL);
