@@ -66,18 +66,19 @@ typedef struct tagTAB_COMPLETION {
 
 struct readline_session_context {
 	PTAB_COMPLETION  tc;
+	STRING           prompt;
 	WINDOW          *act;
 	bool             insert_mode;
 	bool             no_bufspc;
-	char            *prompt;
 	int              bufpos;
-	int              n_insert;
+	int              numins;
 	int              prompt_size;
 	wchar_t         *buffer;
 };
 
 __SWIRC_BEGIN_DECLS
-extern PREADLINE_POS g_readline_pos;
+extern PREADLINE_POS	 g_readline_pos;
+extern const int	 g_readline_bufsize;
 
 extern bool	g_readline_loop;
 extern bool	g_resize_requested;
@@ -93,8 +94,8 @@ void readline_deinit(void);
 /*lint -sem(readline, r_null) */
 
 WINDOW	*readline_get_active_pwin(void);
-char	*readline(const char *prompt);
-char	*readline_finalize_out_string_exported(const wchar_t *);
+STRING	 readline(CSTRING prompt);
+STRING	 readline_finalize_out_string_exported(const wchar_t *);
 void	 readline_handle_backspace(volatile struct readline_session_context *);
 void	 readline_handle_key_exported(volatile struct readline_session_context *,
 	     wint_t);
