@@ -49,13 +49,13 @@
 
 static void
 do_work(volatile struct readline_session_context *ctx, const wchar_t *cmd,
-    const char *s)
+    CSTRING s)
 {
 	const size_t cmdlen = wcslen(cmd);
 	const size_t slen = strlen(s);
 	size_t i;
 
-	while (ctx->n_insert != 0)
+	while (ctx->numins != 0)
 		readline_handle_backspace(ctx);
 	for (i = 0; i < cmdlen; i++)
 		readline_handle_key_exported(ctx, cmd[i]);
@@ -65,95 +65,95 @@ do_work(volatile struct readline_session_context *ctx, const wchar_t *cmd,
 
 static void
 auto_complete_connect(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/connect ", s);
 }
 
 static void
 auto_complete_help(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/help ", s);
 }
 
 static void
 auto_complete_msg(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/msg ", s);
 }
 
 static void
 auto_complete_notice(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/notice ", s);
 }
 
 static void
 auto_complete_query(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/query ", s);
 }
 
 static void
 auto_complete_sasl(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/sasl ", s);
 }
 
 static void
 auto_complete_setting(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/set ", s);
 }
 
 static void
 auto_complete_theme(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/theme ", s);
 }
 
 static void
 auto_complete_time(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/time ", s);
 }
 
 static void
 auto_complete_version(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/version ", s);
 }
 
 static void
 auto_complete_whois(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/whois ", s);
 }
 
 static void
 auto_complete_znc_cmd(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	do_work(ctx, L"/znc ", s);
 }
 
 static void
 auto_complete_command(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	const size_t slen = strlen(s);
 
-	while (ctx->n_insert != 0)
+	while (ctx->numins != 0)
 		readline_handle_backspace(ctx);
 
 	readline_handle_key_exported(ctx, L'/');
@@ -164,11 +164,11 @@ auto_complete_command(volatile struct readline_session_context *ctx,
 
 static void
 auto_complete_channel_user(volatile struct readline_session_context *ctx,
-    const char *s)
+    CSTRING s)
 {
 	const size_t slen = strlen(s);
 
-	while (ctx->n_insert != 0)
+	while (ctx->numins != 0)
 		readline_handle_backspace(ctx);
 	for (size_t i = 0; i < slen; i++)
 		readline_handle_key_exported(ctx, btowc(s[i]));
@@ -179,34 +179,34 @@ auto_complete_channel_user(volatile struct readline_session_context *ctx,
 static bool
 buf_contains_disallowed_chars(const volatile struct readline_session_context *ctx)
 {
-	char *s = readline_finalize_out_string_exported(ctx->buffer);
+	STRING s = readline_finalize_out_string_exported(ctx->buffer);
 	const bool yes_no = (strpbrk(s, g_textdeco_chars) != NULL);
 	free(s);
 	return yes_no;
 }
 
 static PTEXTBUF
-get_matches_common(const char *p)
+get_matches_common(CSTRING srch)
 {
 	if (!is_irc_channel(ACTWINLABEL)) {
-		if (!is_irc_channel(p))
-			return get_list_of_matching_queries(p);
+		if (!is_irc_channel(srch))
+			return get_list_of_matching_queries(srch);
 		else
-			return get_list_of_matching_channels(p);
+			return get_list_of_matching_channels(srch);
 	}
-	if (is_irc_channel(p))
-		return get_list_of_matching_channels(p);
-	return get_list_of_matching_channel_users(ACTWINLABEL, p);
+	if (is_irc_channel(srch))
+		return get_list_of_matching_channels(srch);
+	return get_list_of_matching_channel_users(ACTWINLABEL, srch);
 }
 
-static inline char *
+static inline STRING
 get_search_var(const volatile struct readline_session_context *ctx)
 {
 	return addrof(ctx->tc->search_var[0]);
 }
 
 static void
-output_error(const char *msg)
+output_error(CSTRING msg)
 {
 	PRINTTEXT_CONTEXT	ctx;
 
@@ -218,7 +218,7 @@ output_error(const char *msg)
 static int
 store_search_var(const volatile struct readline_session_context *ctx)
 {
-	char *s = readline_finalize_out_string_exported(ctx->buffer);
+	STRING s = readline_finalize_out_string_exported(ctx->buffer);
 
 	const int store_res = sw_strcpy(ctx->tc->search_var, s,
 	    ARRAY_SIZE(ctx->tc->search_var));
@@ -230,7 +230,7 @@ store_search_var(const volatile struct readline_session_context *ctx)
 PTAB_COMPLETION
 readline_tab_comp_ctx_new(void)
 {
-	static TAB_COMPLETION	ctx;
+	static TAB_COMPLETION	ctx = { 0 };
 
 	BZERO(ctx.search_var, sizeof ctx.search_var);
 
@@ -492,11 +492,11 @@ init_mode_for_znc_cmds(volatile struct readline_session_context *ctx)
 
 static void
 init_mode_for_commands(volatile struct readline_session_context *ctx,
-    const bool n_insert_greater_than_one)
+    const bool numins_greater_than_one)
 {
 	char	*p = addrof(ctx->tc->search_var[1]);
 
-	if (!n_insert_greater_than_one || (ctx->tc->matches =
+	if (!numins_greater_than_one || (ctx->tc->matches =
 	    get_list_of_matching_commands(p)) == NULL) {
 		output_error("no magic");
 		return;
@@ -521,7 +521,7 @@ init_mode_for_channel_users(volatile struct readline_session_context *ctx)
 	ctx->tc->isInCirculationModeForChanUsers = true;
 }
 
-static char *
+static STRING
 next_text(PTAB_COMPLETION tc)
 {
 	tc->elmt = tc->elmt->next;
@@ -563,7 +563,7 @@ init_mode(volatile struct readline_session_context *ctx)
 	else if (!strncmp(get_search_var(ctx), "/znc ", 5))
 		init_mode_for_znc_cmds(ctx);
 	else if (ctx->tc->search_var[0] == '/')
-		init_mode_for_commands(ctx, (ctx->n_insert > 1));
+		init_mode_for_commands(ctx, (ctx->numins > 1));
 	else if (is_irc_channel(ACTWINLABEL))
 		init_mode_for_channel_users(ctx);
 }
@@ -571,7 +571,7 @@ init_mode(volatile struct readline_session_context *ctx)
 void
 readline_handle_tab(volatile struct readline_session_context *ctx)
 {
-	if (ctx->n_insert == 0 || ctx->insert_mode ||
+	if (ctx->numins == 0 || ctx->insert_mode ||
 	    buf_contains_disallowed_chars(ctx)) {
 		output_error("no magic");
 		readline_tab_comp_ctx_reset(ctx->tc);
