@@ -34,7 +34,7 @@ __SWIRC_END_DECLS
 /* Inline function definitions
    =========================== */
 
-#if defined(LINUX) && !defined(_GNU_SOURCE)
+#if (defined(HURD) || defined(LINUX)) && !defined(_GNU_SOURCE)
 #define _GNU_SOURCE
 #endif
 #include <string.h>
