@@ -78,8 +78,8 @@
    ===================== */
 
 struct hInstall_context {
-	char	*label;
-	char	*title;
+	STRING	 label;
+	STRING	 title;
 	PANEL	*pan;
 	int	 refnum;
 };
@@ -102,7 +102,7 @@ static PIRC_WINDOW hash_table[200] = { NULL };
 /* -------------------------------------------------- */
 
 static void
-add_match(PTEXTBUF matches, const char *what)
+add_match(PTEXTBUF matches, CSTRING what)
 {
 	if (textBuf_size(matches) != 0) {
 		if ((errno = textBuf_ins_next(matches, textBuf_tail(matches),
@@ -124,7 +124,7 @@ apply_window_options(WINDOW *win)
 		(void) scrollok(win, true);
 }
 
-static int
+static errno_t
 change_window(PIRC_WINDOW window)
 {
 	WINDOW *pwin;
@@ -144,7 +144,7 @@ change_window(PIRC_WINDOW window)
 	statusbar_update_display_beta();
 
 	if ((pwin = readline_get_active_pwin()) != NULL) {
-		char *prompt;
+		STRING prompt;
 
 		(void) werase(pwin);
 		prompt = get_prompt();
@@ -528,7 +528,7 @@ windowSystem_deinit(void)
  * error
  */
 PIRC_WINDOW
-window_by_label(const char *label)
+window_by_label(CSTRING label)
 {
 	PIRC_WINDOW window;
 
@@ -563,7 +563,7 @@ window_by_refnum(int refnum)
 }
 
 PTEXTBUF
-get_list_of_matching_channels(const char *search_var)
+get_list_of_matching_channels(CSTRING search_var)
 {
 	PTEXTBUF	matches = textBuf_new();
 
@@ -583,7 +583,7 @@ get_list_of_matching_channels(const char *search_var)
 }
 
 PTEXTBUF
-get_list_of_matching_queries(const char *search_var)
+get_list_of_matching_queries(CSTRING search_var)
 {
 	PTEXTBUF	matches = textBuf_new();
 
@@ -606,8 +606,8 @@ get_list_of_matching_queries(const char *search_var)
 /**
  * Change window to the one specified by @label
  */
-int
-change_window_by_label(const char *label)
+errno_t
+change_window_by_label(CSTRING label)
 {
 	return change_window(window_by_label(label));
 }
@@ -615,7 +615,7 @@ change_window_by_label(const char *label)
 /**
  * Change window to the one specified by @refnum
  */
-int
+errno_t
 change_window_by_refnum(int refnum)
 {
 	return change_window(window_by_refnum(refnum));
@@ -624,8 +624,8 @@ change_window_by_refnum(int refnum)
 /**
  * Destroy a chat window
  */
-int
-destroy_chat_window(const char *label)
+errno_t
+destroy_chat_window(CSTRING label)
 {
 	PIRC_WINDOW window;
 
@@ -637,7 +637,7 @@ destroy_chat_window(const char *label)
 
 	hUndef(window);
 	reassign_window_refnums();
-	const int ret = change_window_by_refnum(g_ntotal_windows);
+	const errno_t ret = change_window_by_refnum(g_ntotal_windows);
 	(void) ret;
 	sw_assert_perror(ret);
 
@@ -647,8 +647,8 @@ destroy_chat_window(const char *label)
 /**
  * Spawn a chat window with given label and title
  */
-int
-spawn_chat_window(const char *label, const char *title)
+errno_t
+spawn_chat_window(CSTRING label, CSTRING title)
 {
 	const int ntotalp1 = g_ntotal_windows + 1;
 	struct integer_context intctx = {
@@ -668,14 +668,14 @@ spawn_chat_window(const char *label, const char *title)
 	struct hInstall_context inst_ctx;
 	PIRC_WINDOW entry;
 
-	inst_ctx.label  = (char *) label;
-	inst_ctx.title  = (char *) title;
+	inst_ctx.label  = (STRING) label;
+	inst_ctx.title  = (STRING) title;
 	inst_ctx.pan    = term_new_panel(LINES - 2, 0, 1, 0);
 	inst_ctx.refnum = g_ntotal_windows + 1;
 
 	entry = hInstall(&inst_ctx);
 	apply_window_options(panel_window(entry->pan));
-	const int ret = change_window_by_label(entry->label);
+	const errno_t ret = change_window_by_label(entry->label);
 	(void) ret;
 	sw_assert_perror(ret);
 
@@ -692,7 +692,7 @@ spawn_chat_window(const char *label, const char *title)
  * Set new window title
  */
 void
-new_window_title(const char *label, const char *title)
+new_window_title(CSTRING label, CSTRING title)
 {
 	PIRC_WINDOW window;
 
